pygeodesy.geodesici._IntersectBase

Package pygeodesy :: Module geodesici :: Class _IntersectBase |
[frames] | no frames]

# Class _IntersectBase

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
                      _IntersectBase

Known Subclasses:
  - Intersectool
  - , Intersector

(INTERNAL) Base class for Intersectool and Intersector.

Instance Methods
__init__(self, geodesic, **name) x.__init__(...) initializes x; see help(type(x)) for signature |
All(self, glA, glB, **kwds) (INTERNAL) Must be overloaded. |
intersect7(self, start1, end1, start2, end2, X0=XDict(c=0, sA=0.0, sB=0.0, sX0=0.0), aMaX0=0, sMaX0=40075016.6856, **LatLon_and_kwds) Yield the intersections of two geodesic lines, each defined by a start and end point or by a start point and an azimuth (bearing from North). |
k2kAkB(self, k) Unravel `k` into `kA` and `kB`. |
Line(self, lat1, lon1, azi1_lat2, *lon2, **name) (INTERNAL) Must be overloaded. |
Next5s(self, glA, glB, X0=XDict(c=0, sA=0.0, sB=0.0, sX0=0.0), aMax=1801, sMax=0, **unused) DEPRECATED on 2024.07.02, use method `All5`. |
Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr`, `toStr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| a Get the equatorial radius, semi-axis (`meter`).
| equatoradius Get the equatorial radius, semi-axis (`meter`).
| datum Get the geodesic's datum (`Datum`).
| ellipsoid Get the `geodesic`'s ellipsoid (`Ellipsoid`).
| f Get the flattening (`scalar`), `0` for spherical, negative for prolate.
| flattening Get the flattening (`scalar`), `0` for spherical, negative for prolate.
| geodesic Get the `Geodesic` (`GeodesicExact, GeodesicSolve, or ...`).
| R Get the authalic earth radius (`meter`).
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, geodesic, **name) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### intersect7 (self, start1, end1, start2, end2, X0=XDict(c=0, sA=0.0, sB=0.0, sX0=0.0), aMaX0=0, sMaX0=40075016.6856, **LatLon_and_kwds) |
Yield the intersections of two geodesic lines, each defined by a start and end point or by a start point and an azimuth (bearing from North). Arguments: `start1` - Start point of the first line (`LatLon`). `end1` - End point of the first line (`LatLon`) or the azimuth at the `start1` point (compass `degrees360`). `start2` - Start point of the second line (`LatLon`). `end2` - End point of the second line (`LatLon`) or the azimuth at the `start2` point (compass `degrees360`). `X0` - Optional origin for L1-distances (XDict) or `None` for the Middle, otherwise `XDiff_(0, 0)`. `aMaX0` - Upper limit for the angular L1-distance (`degrees`) or `None` or `0` for unlimited. `sMaX0_C` - Optional, upper limit `sMaX0=2*PI*R` for the L1-distance to `X0` (`meter`). `LatLon_and_kwds` - Optional class `LatLon=None` to return intersection points and optional, additional `LatLon` keyword arguments. Returns: Yield an Intersect7Tuple`(A, B, sAB, aAB, c, kA, kB)` for every intersection found, with `A` and `B` each a `LatLon` or if `LatLon is None` or not specified, a LatLon4Tuple`(lat, lon, height, datum)` with `height 0` and this `datum`. Raises: `GeodesicError` - Invalid `start1`, `end1`, `start2` or `end2` or `end1` and `end2` differ in type. `IntersectionError` - No convergence. Note: The `lat` and `lon` attr of `start1`, `end1`, `start2` and `end2` are used verbatim, ignoring `datum` or `ellipsoid`.

### k2kAkB (self, k) |
Unravel `k` into `kA` and `kB`. Arguments: `k` - Segment indicator `kA * 3 + kB` (`int`). Returns: An `ADict(k=k, kA=kA, kB=kB)`. Raises: `GeodesicError` - Invalid `k`.

### Next5s (self, glA, glB, X0=XDict(c=0, sA=0.0, sB=0.0, sX0=0.0), aMax=1801, sMax=0, **unused) |
DEPRECATED on 2024.07.02, use method `All5`. Decorators: `@deprecated_method`

Property Details

### a Get the equatorial radius, semi-axis (`meter`). Get method: a(self) - Get the equatorial radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### equatoradius Get the equatorial radius, semi-axis (`meter`). Get method: a(self) - Get the equatorial radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### datum Get the geodesic's datum (`Datum`). Get method: datum(self) - Get the geodesic's datum (`Datum`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### ellipsoid Get the `geodesic`'s ellipsoid (`Ellipsoid`). Get method: ellipsoid(self) - Get the `geodesic`'s ellipsoid (`Ellipsoid`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### f Get the flattening (`scalar`), `0` for spherical, negative for prolate. Get method: f(self) - Get the flattening (`scalar`), `0` for spherical, negative for prolate. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### flattening Get the flattening (`scalar`), `0` for spherical, negative for prolate. Get method: f(self) - Get the flattening (`scalar`), `0` for spherical, negative for prolate. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### geodesic Get the `Geodesic` (`GeodesicExact, GeodesicSolve, or ...`). Get method: geodesic(self) - Get the `Geodesic` (`GeodesicExact, GeodesicSolve, or ...`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### R Get the authalic earth radius (`meter`). Get method: R(self) - Get the authalic earth radius (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.